@@ -172,14 +172,6 @@ class QueryPlan:
                     raise PlanningException(f'Can\'t request table columns when applying timeseries predictor, but found: {str(target)}. '
                                             f'Try to request the same column from the predictor, like "SELECT pred.column".')
 
-        def is_greater_than_latest(op):
-            if isinstance(op, BinaryOperation) and Latest() in op.args:
-                if op.op == '>' and op.args[1] == Latest() and op.args[0] != Latest():
-                    return True
-                else:
-                    raise PlanningException(f'Can only use "<predictor order_by column> > LATEST", found: {str(op)}')
-            return False
-
         def find_time_filter(op, time_column_name):
             if not op:
                 return
@@ -220,7 +212,7 @@ class QueryPlan:
             """Error if the where condition caontains invalid ops, is nested or filters on some column that's not time or partition"""
             if not op:
                 return
-            allowed_ops = ['and', '>', '>=', '=', '<', '<=', 'between']
+            allowed_ops = ['and', '>', '>=', '=', '<', '<=', 'between', 'in']
             if not allow_and:
                 allowed_ops.remove('and')
             if op.op not in allowed_ops:
@@ -282,6 +274,23 @@ class QueryPlan:
                                         )
             integration_select.where = find_and_remove_time_filter(integration_select.where, time_filter)
             self.plan_integration_select(integration_select)
+        elif isinstance(time_filter, BinaryOperation) and time_filter.op in ('>', '>='):
+            new_time_filter_op = {'>': '<=', '>=': '<'}[time_filter.op]
+            time_filter.op = new_time_filter_op
+            integration_select = Select(targets=[Star()],
+                                        from_table=table,
+                                        where=query.where,
+                                        order_by=order_by,
+                                        limit=Constant(predictor_window),
+                                        )
+            self.plan_integration_select(integration_select)
+        elif isinstance(time_filter, BinaryOperation) and time_filter.op in ('<', '<='):
+            integration_select = Select(targets=[Star()],
+                                        from_table=table,
+                                        where=query.where,
+                                        order_by=order_by,
+                                        )
+            self.plan_integration_select(integration_select)
         else:
             integration_select = Select(targets=[Star()],
                                         from_table=table,
